package com.ibm.bsf.engines.rexx;

import java.util.*;

/** Class to allow Rexx enumerating objects of classes implementing the Enumeration interface.
 * For unknwon reasons (as of 2003-02-12) invoking the Enumeration methods on Java objects
 * (like on System.properties()) causes IllegalAccessException on all tested Java versions
 * (Sun's Windows versions of: 1.1.8, 1.2.2, 1.3.1_06, 1.4.1_01).
 *
 * <p>Interestingly, wrapping such objects into this class, allows access again (without raising
 * an exception)!
 *
 * <p>(It seems that the method reflection mechanism cannot cope with inner classes implementing
 * the interface but not being declared to be public!)
 *
 * @author Rony G. Flatscher
 * @version 0.9.0 (2003-02-12)
 * @since   2003-02-12 by rgf
 */
public class EnumerationWrapper implements Enumeration
{

    /** Private object storing the object to enumerate. */
    private Object enumObj;

    // public EnumerationWrapper (Object enum)
    public EnumerationWrapper (Enumeration enum)
    {
        this.enumObj=enum;
    }

    // Enumeration interface implementation
    /** Implements the interface {@link java.util.Enumeration#hasMoreElements() java.util.Enumeration.hasMoreElements()}.
     */
    public boolean hasMoreElements()
    {
        return ((Enumeration) enumObj).hasMoreElements();
    }

    /** Implements the interface {@link java.util.Enumeration#nextElemetn() java.util.Enumeration.nextElement()}.
     *
     * @exception NoSuchElementException raised, if using the Enumerator interface and moving
     *                                   beyond the end of the supplier object.
     */
    public Object nextElement()
    {
        return ((Enumeration) enumObj).nextElement();
    }
}
